@@ -6,6 +6,7 @@ types: list[str] = [
     "AWS::ACMPCA::CertificateAuthority",
     "AWS::ACMPCA::CertificateAuthorityActivation",
     "AWS::ACMPCA::Permission",
+    "AWS::ARCRegionSwitch::Plan",
     "AWS::ARCZonalShift::AutoshiftObserverNotificationStatus",
     "AWS::ARCZonalShift::ZonalAutoshiftConfiguration",
     "AWS::AccessAnalyzer::Analyzer",
@@ -59,9 +60,11 @@ types: list[str] = [
     "AWS::CDK::Metadata",
     "AWS::CertificateManager::Certificate",
     "AWS::CloudFormation::CustomResource",
+    "AWS::CloudFormation::GuardHook",
     "AWS::CloudFormation::HookDefaultVersion",
     "AWS::CloudFormation::HookTypeConfig",
     "AWS::CloudFormation::HookVersion",
+    "AWS::CloudFormation::LambdaHook",
     "AWS::CloudFormation::Macro",
     "AWS::CloudFormation::ResourceDefaultVersion",
     "AWS::CloudFormation::ResourceVersion",
@@ -91,6 +94,7 @@ types: list[str] = [
     "AWS::CloudWatch::CompositeAlarm",
     "AWS::CloudWatch::Dashboard",
     "AWS::CloudWatch::InsightRule",
+    "AWS::CloudWatch::MetricStream",
     "AWS::CodeDeploy::Application",
     "AWS::CodeDeploy::DeploymentConfig",
     "AWS::CodeDeploy::DeploymentGroup",
@@ -100,8 +104,13 @@ types: list[str] = [
     "AWS::Config::ConfigRule",
     "AWS::Config::ConfigurationAggregator",
     "AWS::Config::ConfigurationRecorder",
+    "AWS::Config::ConformancePack",
     "AWS::Config::DeliveryChannel",
+    "AWS::Config::OrganizationConformancePack",
     "AWS::Config::StoredQuery",
+    "AWS::ControlTower::EnabledBaseline",
+    "AWS::ControlTower::EnabledControl",
+    "AWS::ControlTower::LandingZone",
     "AWS::DLM::LifecyclePolicy",
     "AWS::DMS::DataProvider",
     "AWS::DMS::InstanceProfile",
@@ -170,6 +179,7 @@ types: list[str] = [
     "AWS::EC2::TransitGateway",
     "AWS::EC2::TransitGatewayAttachment",
     "AWS::EC2::TransitGatewayConnect",
+    "AWS::EC2::TransitGatewayConnectPeer",
     "AWS::EC2::TransitGatewayMulticastDomain",
     "AWS::EC2::TransitGatewayMulticastDomainAssociation",
     "AWS::EC2::TransitGatewayMulticastGroupMember",
@@ -229,6 +239,7 @@ types: list[str] = [
     "AWS::ElastiCache::ReplicationGroup",
     "AWS::ElastiCache::SecurityGroup",
     "AWS::ElastiCache::SecurityGroupIngress",
+    "AWS::ElastiCache::ServerlessCache",
     "AWS::ElastiCache::SubnetGroup",
     "AWS::ElastiCache::User",
     "AWS::ElastiCache::UserGroup",
@@ -417,6 +428,12 @@ types: list[str] = [
     "AWS::WAF::SqlInjectionMatchSet",
     "AWS::WAF::WebACL",
     "AWS::WAF::XssMatchSet",
+    "AWS::WAFv2::IPSet",
+    "AWS::WAFv2::LoggingConfiguration",
+    "AWS::WAFv2::RegexPatternSet",
+    "AWS::WAFv2::RuleGroup",
+    "AWS::WAFv2::WebACL",
+    "AWS::WAFv2::WebACLAssociation",
     "AWS::WorkSpaces::Workspace",
     "AWS::XRay::Group",
     "AWS::XRay::ResourcePolicy",
@@ -432,6 +449,9 @@ cached: list[str] = [
     "aws-acmpca-certificateauthority.json",
     "aws-acmpca-certificateauthorityactivation.json",
     "aws-acmpca-permission.json",
+    "aws-amazonmq-broker.json",
+    "aws-amazonmq-configuration.json",
+    "aws-amazonmq-configurationassociation.json",
     "aws-apigateway-account.json",
     "aws-apigateway-apikey.json",
     "aws-apigateway-authorizer.json",
@@ -459,6 +479,9 @@ cached: list[str] = [
     "aws-appconfig-extension.json",
     "aws-appconfig-extensionassociation.json",
     "aws-appconfig-hostedconfigurationversion.json",
+    "aws-applicationautoscaling-scalabletarget.json",
+    "aws-applicationautoscaling-scalingpolicy.json",
+    "aws-arcregionswitch-plan.json",
     "aws-arczonalshift-autoshiftobservernotificationstatus.json",
     "aws-arczonalshift-zonalautoshiftconfiguration.json",
     "aws-autoscaling-autoscalinggroup.json",
@@ -472,15 +495,16 @@ cached: list[str] = [
     "aws-backup-backupvault.json",
     "aws-batch-computeenvironment.json",
     "aws-batch-consumableresource.json",
-    "aws-batch-jobdefinition.json",
     "aws-batch-jobqueue.json",
     "aws-batch-schedulingpolicy.json",
     "aws-batch-serviceenvironment.json",
     "aws-certificatemanager-certificate.json",
     "aws-cloudformation-customresource.json",
+    "aws-cloudformation-guardhook.json",
     "aws-cloudformation-hookdefaultversion.json",
     "aws-cloudformation-hooktypeconfig.json",
     "aws-cloudformation-hookversion.json",
+    "aws-cloudformation-lambdahook.json",
     "aws-cloudformation-macro.json",
     "aws-cloudformation-resourcedefaultversion.json",
     "aws-cloudformation-resourceversion.json",
@@ -508,13 +532,18 @@ cached: list[str] = [
     "aws-cloudwatch-compositealarm.json",
     "aws-cloudwatch-dashboard.json",
     "aws-cloudwatch-insightrule.json",
+    "aws-cloudwatch-metricstream.json",
     "aws-codedeploy-deploymentgroup.json",
     "aws-config-aggregationauthorization.json",
     "aws-config-configrule.json",
     "aws-config-configurationaggregator.json",
     "aws-config-configurationrecorder.json",
+    "aws-config-conformancepack.json",
     "aws-config-deliverychannel.json",
+    "aws-config-organizationconformancepack.json",
     "aws-config-storedquery.json",
+    "aws-controltower-enabledbaseline.json",
+    "aws-controltower-enabledcontrol.json",
     "aws-datasync-agent.json",
     "aws-datasync-locationazureblob.json",
     "aws-datasync-locationhdfs.json",
@@ -548,7 +577,6 @@ cached: list[str] = [
     "aws-ec2-ipamscope.json",
     "aws-ec2-keypair.json",
     "aws-ec2-launchtemplate.json",
-    "aws-ec2-natgateway.json",
     "aws-ec2-networkacl.json",
     "aws-ec2-networkaclentry.json",
     "aws-ec2-networkinsightsaccessscope.json",
@@ -576,6 +604,7 @@ cached: list[str] = [
     "aws-ec2-transitgateway.json",
     "aws-ec2-transitgatewayattachment.json",
     "aws-ec2-transitgatewayconnect.json",
+    "aws-ec2-transitgatewayconnectpeer.json",
     "aws-ec2-transitgatewaymulticastdomain.json",
     "aws-ec2-transitgatewaymulticastdomainassociation.json",
     "aws-ec2-transitgatewaymulticastgroupmember.json",
@@ -629,6 +658,7 @@ cached: list[str] = [
     "aws-elasticache-replicationgroup.json",
     "aws-elasticache-securitygroup.json",
     "aws-elasticache-securitygroupingress.json",
+    "aws-elasticache-serverlesscache.json",
     "aws-elasticache-subnetgroup.json",
     "aws-elasticache-user.json",
     "aws-elasticache-usergroup.json",
@@ -642,6 +672,7 @@ cached: list[str] = [
     "aws-emr-cluster.json",
     "aws-emr-instancefleetconfig.json",
     "aws-emr-instancegroupconfig.json",
+    "aws-emr-securityconfiguration.json",
     "aws-emr-step.json",
     "aws-events-eventbus.json",
     "aws-events-rule.json",
@@ -695,12 +726,15 @@ cached: list[str] = [
     "aws-lambda-permission.json",
     "aws-lambda-version.json",
     "aws-logs-delivery.json",
+    "aws-logs-deliverydestination.json",
     "aws-logs-deliverysource.json",
     "aws-logs-destination.json",
     "aws-logs-loggroup.json",
     "aws-logs-logstream.json",
+    "aws-logs-metricfilter.json",
     "aws-logs-querydefinition.json",
     "aws-logs-resourcepolicy.json",
+    "aws-logs-subscriptionfilter.json",
     "aws-oam-link.json",
     "aws-oam-sink.json",
     "aws-opensearchservice-domain.json",
@@ -796,6 +830,10 @@ cached: list[str] = [
     "aws-verifiedpermissions-policytemplate.json",
     "aws-waf-bytematchset.json",
     "aws-waf-sqlinjectionmatchset.json",
+    "aws-wafv2-ipset.json",
+    "aws-wafv2-regexpatternset.json",
+    "aws-wafv2-rulegroup.json",
+    "aws-wafv2-webaclassociation.json",
     "aws-workspaces-workspace.json",
     "aws-xray-group.json",
     "aws-xray-resourcepolicy.json",
