@@ -6,6 +6,7 @@ types: list[str] = [
     "AWS::ACMPCA::CertificateAuthority",
     "AWS::ACMPCA::CertificateAuthorityActivation",
     "AWS::ACMPCA::Permission",
+    "AWS::APS::AnomalyDetector",
     "AWS::APS::ResourcePolicy",
     "AWS::APS::RuleGroupsNamespace",
     "AWS::APS::Workspace",
@@ -283,6 +284,10 @@ types: list[str] = [
     "AWS::EC2::NatGateway",
     "AWS::EC2::NetworkAcl",
     "AWS::EC2::NetworkAclEntry",
+    "AWS::EC2::NetworkInsightsAccessScope",
+    "AWS::EC2::NetworkInsightsAccessScopeAnalysis",
+    "AWS::EC2::NetworkInsightsAnalysis",
+    "AWS::EC2::NetworkInsightsPath",
     "AWS::EC2::NetworkInterface",
     "AWS::EC2::NetworkInterfaceAttachment",
     "AWS::EC2::NetworkInterfacePermission",
@@ -615,13 +620,20 @@ types: list[str] = [
     "AWS::NetworkFirewall::RuleGroup",
     "AWS::NetworkFirewall::TLSInspectionConfiguration",
     "AWS::NetworkFirewall::VpcEndpointAssociation",
+    "AWS::NetworkManager::ConnectAttachment",
+    "AWS::NetworkManager::ConnectPeer",
+    "AWS::NetworkManager::CoreNetwork",
     "AWS::NetworkManager::CustomerGatewayAssociation",
     "AWS::NetworkManager::Device",
     "AWS::NetworkManager::GlobalNetwork",
     "AWS::NetworkManager::Link",
     "AWS::NetworkManager::LinkAssociation",
     "AWS::NetworkManager::Site",
+    "AWS::NetworkManager::SiteToSiteVpnAttachment",
+    "AWS::NetworkManager::TransitGatewayPeering",
     "AWS::NetworkManager::TransitGatewayRegistration",
+    "AWS::NetworkManager::TransitGatewayRouteTableAttachment",
+    "AWS::NetworkManager::VpcAttachment",
     "AWS::Oam::Link",
     "AWS::Oam::Sink",
     "AWS::OpenSearchServerless::AccessPolicy",
@@ -904,6 +916,9 @@ cached: list[str] = [
     "aws-acmpca-certificateauthority.json",
     "aws-acmpca-certificateauthorityactivation.json",
     "aws-acmpca-permission.json",
+    "aws-amazonmq-broker.json",
+    "aws-amazonmq-configuration.json",
+    "aws-amazonmq-configurationassociation.json",
     "aws-apigateway-account.json",
     "aws-apigateway-apikey.json",
     "aws-apigateway-authorizer.json",
@@ -968,14 +983,13 @@ cached: list[str] = [
     "aws-appstream-fleet.json",
     "aws-appstream-stack.json",
     "aws-appstream-stackfleetassociation.json",
+    "aws-aps-anomalydetector.json",
     "aws-aps-resourcepolicy.json",
     "aws-aps-rulegroupsnamespace.json",
     "aws-aps-workspace.json",
     "aws-arczonalshift-autoshiftobservernotificationstatus.json",
     "aws-arczonalshift-zonalautoshiftconfiguration.json",
     "aws-athena-datacatalog.json",
-    "aws-athena-namedquery.json",
-    "aws-athena-preparedstatement.json",
     "aws-athena-workgroup.json",
     "aws-autoscaling-autoscalinggroup.json",
     "aws-autoscaling-launchconfiguration.json",
@@ -991,10 +1005,10 @@ cached: list[str] = [
     "aws-backupgateway-hypervisor.json",
     "aws-batch-computeenvironment.json",
     "aws-batch-consumableresource.json",
-    "aws-batch-jobdefinition.json",
     "aws-batch-jobqueue.json",
     "aws-batch-schedulingpolicy.json",
     "aws-batch-serviceenvironment.json",
+    "aws-bedrock-agent.json",
     "aws-bedrock-agentalias.json",
     "aws-bedrock-blueprint.json",
     "aws-bedrock-dataautomationproject.json",
@@ -1041,6 +1055,7 @@ cached: list[str] = [
     "aws-codedeploy-deploymentconfig.json",
     "aws-codedeploy-deploymentgroup.json",
     "aws-codepipeline-customactiontype.json",
+    "aws-codepipeline-webhook.json",
     "aws-cognito-identitypool.json",
     "aws-cognito-identitypoolprincipaltag.json",
     "aws-cognito-identitypoolroleattachment.json",
@@ -1122,8 +1137,6 @@ cached: list[str] = [
     "aws-docdb-dbinstance.json",
     "aws-docdb-dbsubnetgroup.json",
     "aws-docdb-eventsubscription.json",
-    "aws-dynamodb-globaltable.json",
-    "aws-dynamodb-table.json",
     "aws-ec2-capacityreservation.json",
     "aws-ec2-capacityreservationfleet.json",
     "aws-ec2-clientvpnendpoint.json",
@@ -1157,6 +1170,10 @@ cached: list[str] = [
     "aws-ec2-natgateway.json",
     "aws-ec2-networkacl.json",
     "aws-ec2-networkaclentry.json",
+    "aws-ec2-networkinsightsaccessscope.json",
+    "aws-ec2-networkinsightsaccessscopeanalysis.json",
+    "aws-ec2-networkinsightsanalysis.json",
+    "aws-ec2-networkinsightspath.json",
     "aws-ec2-networkinterface.json",
     "aws-ec2-networkinterfacepermission.json",
     "aws-ec2-placementgroup.json",
@@ -1220,7 +1237,6 @@ cached: list[str] = [
     "aws-ecs-cluster.json",
     "aws-ecs-clustercapacityproviderassociations.json",
     "aws-ecs-primarytaskset.json",
-    "aws-ecs-service.json",
     "aws-ecs-taskdefinition.json",
     "aws-ecs-taskset.json",
     "aws-efs-accesspoint.json",
@@ -1259,7 +1275,6 @@ cached: list[str] = [
     "aws-emrcontainers-virtualcluster.json",
     "aws-emrserverless-application.json",
     "aws-events-archive.json",
-    "aws-events-eventbuspolicy.json",
     "aws-eventschemas-discoverer.json",
     "aws-eventschemas-registry.json",
     "aws-eventschemas-registrypolicy.json",
@@ -1456,19 +1471,23 @@ cached: list[str] = [
     "aws-neptune-dbparametergroup.json",
     "aws-neptune-dbsubnetgroup.json",
     "aws-neptune-eventsubscription.json",
-    "aws-networkfirewall-firewall.json",
-    "aws-networkfirewall-firewallpolicy.json",
     "aws-networkfirewall-loggingconfiguration.json",
-    "aws-networkfirewall-rulegroup.json",
     "aws-networkfirewall-tlsinspectionconfiguration.json",
     "aws-networkfirewall-vpcendpointassociation.json",
+    "aws-networkmanager-connectattachment.json",
+    "aws-networkmanager-connectpeer.json",
+    "aws-networkmanager-corenetwork.json",
     "aws-networkmanager-customergatewayassociation.json",
     "aws-networkmanager-device.json",
     "aws-networkmanager-globalnetwork.json",
     "aws-networkmanager-link.json",
     "aws-networkmanager-linkassociation.json",
     "aws-networkmanager-site.json",
+    "aws-networkmanager-sitetositevpnattachment.json",
+    "aws-networkmanager-transitgatewaypeering.json",
     "aws-networkmanager-transitgatewayregistration.json",
+    "aws-networkmanager-transitgatewayroutetableattachment.json",
+    "aws-networkmanager-vpcattachment.json",
     "aws-oam-link.json",
     "aws-oam-sink.json",
     "aws-opensearchserverless-accesspolicy.json",
@@ -1491,7 +1510,9 @@ cached: list[str] = [
     "aws-organizations-resourcepolicy.json",
     "aws-pcaconnectorscep-challenge.json",
     "aws-pcaconnectorscep-connector.json",
+    "aws-pcs-cluster.json",
     "aws-pcs-computenodegroup.json",
+    "aws-pcs-queue.json",
     "aws-pinpoint-apnschannel.json",
     "aws-pinpoint-apnssandboxchannel.json",
     "aws-pinpoint-apnsvoipchannel.json",
@@ -1574,7 +1595,6 @@ cached: list[str] = [
     "aws-rum-appmonitor.json",
     "aws-s3-accessgrant.json",
     "aws-s3-accessgrantsinstance.json",
-    "aws-s3-accessgrantslocation.json",
     "aws-s3-accesspoint.json",
     "aws-s3-bucket.json",
     "aws-s3-bucketpolicy.json",
@@ -1602,7 +1622,6 @@ cached: list[str] = [
     "aws-sagemaker-processingjob.json",
     "aws-sagemaker-project.json",
     "aws-sagemaker-studiolifecycleconfig.json",
-    "aws-sagemaker-userprofile.json",
     "aws-sagemaker-workteam.json",
     "aws-scheduler-schedule.json",
     "aws-scheduler-schedulegroup.json",
@@ -1628,7 +1647,6 @@ cached: list[str] = [
     "aws-securitylake-subscribernotification.json",
     "aws-servicecatalog-cloudformationproduct.json",
     "aws-servicecatalog-cloudformationprovisionedproduct.json",
-    "aws-servicecatalog-launchnotificationconstraint.json",
     "aws-servicecatalog-launchroleconstraint.json",
     "aws-servicecatalog-portfolioprincipalassociation.json",
     "aws-servicecatalog-serviceaction.json",
@@ -1691,9 +1709,7 @@ cached: list[str] = [
     "aws-timestream-table.json",
     "aws-transfer-agreement.json",
     "aws-transfer-certificate.json",
-    "aws-transfer-connector.json",
     "aws-transfer-profile.json",
-    "aws-transfer-server.json",
     "aws-transfer-user.json",
     "aws-transfer-webapp.json",
     "aws-transfer-workflow.json",
