@@ -7,6 +7,7 @@ SPDX-License-Identifier: MIT-0
 
 from __future__ import annotations
 
+import dataclasses
 import datetime
 import fnmatch
 import gzip
@@ -28,6 +29,7 @@ LOGGER = logging.getLogger(__name__)
 AVAILABILITY_ZONES = {
     "af-south-1": ["af-south-1a", "af-south-1b", "af-south-1c"],
     "ap-east-1": ["ap-east-1a", "ap-east-1b", "ap-east-1c"],
+    "ap-east-2": ["ap-east-2a", "ap-east-2b", "ap-east-2c"],
     "ap-northeast-1": [
         "ap-northeast-1a",
         "ap-northeast-1b",
@@ -60,6 +62,11 @@ AVAILABILITY_ZONES = {
         "ap-southeast-5b",
         "ap-southeast-5c",
     ],
+    "ap-southeast-6": [
+        "ap-southeast-6a",
+        "ap-southeast-6b",
+        "ap-southeast-6c",
+    ],
     "ap-southeast-7": [
         "ap-southeast-7a",
         "ap-southeast-7b",
@@ -101,6 +108,7 @@ AVAILABILITY_ZONES = {
         "me-central-1b",
         "me-central-1c",
     ],
+    "mx-central-1": ["mx-central-1a", "mx-central-1b", "mx-central-1c"],
     "sa-east-1": ["sa-east-1a", "sa-east-1b", "sa-east-1c"],
     "us-east-1": [
         "us-east-1a",
@@ -632,6 +640,8 @@ def format_json_string(json_string):
         """Help convert date/time into strings"""
         if isinstance(o, datetime.datetime):
             return o.__str__()  # pylint: disable=unnecessary-dunder-call
+        elif dataclasses.is_dataclass(o):
+            return dataclasses.asdict(o)
 
     return json.dumps(
         json_string, indent=1, sort_keys=True, separators=(",", ": "), default=converter
